[![Gitter](https://badges.gitter.im/abTEM/community.svg)](https://gitter.im/abTEM/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

# abTEM
ab initio Transmission Electron Microscopy

This program is under development and subject to changes.
